command line interface
======================
.. warning::
   The output of ``--help`` contains help texts for arguments, which
   are not picked up by the documentation generator.

.. click:: dask_hpcconfig.cli:click_app
    :prog: dask-hpcconfig
    :nested: full
